import { IObjectMeta } from "@kubernetes-models/apimachinery/apis/meta/v1/ObjectMeta";
import { Model, ModelData } from "@kubernetes-models/base";
/**
 * ClusterFluentBitConfig is the Schema for the cluster-level fluentbitconfigs API
 */
export interface IClusterFluentBitConfig {
    /**
     * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
     */
    "apiVersion": "fluentbit.fluent.io/v1alpha2";
    /**
     * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
     */
    "kind": "ClusterFluentBitConfig";
    "metadata"?: IObjectMeta;
    /**
     * FluentBitConfigSpec defines the desired state of ClusterFluentBitConfig
     */
    "spec"?: {
        /**
         * Select filter plugins
         */
        "filterSelector"?: {
            /**
             * matchExpressions is a list of label selector requirements. The requirements are ANDed.
             */
            "matchExpressions"?: Array<{
                /**
                 * key is the label key that the selector applies to.
                 */
                "key": string;
                /**
                 * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                 */
                "operator": string;
                /**
                 * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                 */
                "values"?: Array<string>;
            }>;
            /**
             * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
             */
            "matchLabels"?: {
                [key: string]: string;
            };
        };
        /**
         * Select input plugins
         */
        "inputSelector"?: {
            /**
             * matchExpressions is a list of label selector requirements. The requirements are ANDed.
             */
            "matchExpressions"?: Array<{
                /**
                 * key is the label key that the selector applies to.
                 */
                "key": string;
                /**
                 * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                 */
                "operator": string;
                /**
                 * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                 */
                "values"?: Array<string>;
            }>;
            /**
             * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
             */
            "matchLabels"?: {
                [key: string]: string;
            };
        };
        /**
         * If namespace is defined, then the configmap and secret for fluent-bit is in this namespace. If it is not defined, it is in the namespace of the fluentd-operator
         */
        "namespace"?: string;
        /**
         * Select output plugins
         */
        "outputSelector"?: {
            /**
             * matchExpressions is a list of label selector requirements. The requirements are ANDed.
             */
            "matchExpressions"?: Array<{
                /**
                 * key is the label key that the selector applies to.
                 */
                "key": string;
                /**
                 * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                 */
                "operator": string;
                /**
                 * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                 */
                "values"?: Array<string>;
            }>;
            /**
             * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
             */
            "matchLabels"?: {
                [key: string]: string;
            };
        };
        /**
         * Select parser plugins
         */
        "parserSelector"?: {
            /**
             * matchExpressions is a list of label selector requirements. The requirements are ANDed.
             */
            "matchExpressions"?: Array<{
                /**
                 * key is the label key that the selector applies to.
                 */
                "key": string;
                /**
                 * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                 */
                "operator": string;
                /**
                 * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                 */
                "values"?: Array<string>;
            }>;
            /**
             * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
             */
            "matchLabels"?: {
                [key: string]: string;
            };
        };
        /**
         * Service defines the global behaviour of the Fluent Bit engine.
         */
        "service"?: {
            /**
             * If true go to background on start
             */
            "daemon"?: boolean;
            /**
             * Interval to flush output
             */
            "flushSeconds"?: number;
            /**
             * Wait time on exit
             */
            "graceSeconds"?: number;
            /**
             * the error count to meet the unhealthy requirement, this is a sum for all output plugins in a defined HC_Period, example for output error: [2022/02/16 10:44:10] [ warn] [engine] failed to flush chunk '1-1645008245.491540684.flb', retry in 7 seconds: task_id=0, input=forward.1 > output=cloudwatch_logs.3 (out_id=3)
             */
            "hcErrorsCount"?: number;
            /**
             * The time period by second to count the error and retry failure data point
             */
            "hcPeriod"?: number;
            /**
             * the retry failure count to meet the unhealthy requirement, this is a sum for all output plugins in a defined HC_Period, example for retry failure: [2022/02/16 20:11:36] [ warn] [engine] chunk '1-1645042288.260516436.flb' cannot be retried: task_id=0, input=tcp.3 > output=cloudwatch_logs.1
             */
            "hcRetryFailureCount"?: number;
            /**
             * enable Health check feature at http://127.0.0.1:2020/api/v1/health Note: Enabling this will not automatically configure kubernetes to use fluentbit's healthcheck endpoint
             */
            "healthCheck"?: boolean;
            /**
             * Address to listen
             */
            "httpListen"?: string;
            /**
             * Port to listen
             */
            "httpPort"?: number;
            /**
             * If true enable statistics HTTP server
             */
            "httpServer"?: boolean;
            /**
             * File to log diagnostic output
             */
            "logFile"?: string;
            /**
             * Diagnostic level (error/warning/info/debug/trace)
             */
            "logLevel"?: "off" | "error" | "warning" | "info" | "debug" | "trace";
            /**
             * Optional 'parsers' config file (can be multiple)
             */
            "parsersFile"?: string;
            /**
             * Configure a global environment for the storage layer in Service. It is recommended to configure the volume and volumeMount separately for this storage. The hostPath type should be used for that Volume in Fluentbit daemon set.
             */
            "storage"?: {
                /**
                 * This option configure a hint of maximum value of memory to use when processing these records
                 */
                "backlogMemLimit"?: string;
                /**
                 * Enable the data integrity check when writing and reading data from the filesystem
                 */
                "checksum"?: "on" | "off";
                /**
                 * When enabled, irrecoverable chunks will be deleted during runtime, and any other irrecoverable chunk located in the configured storage path directory will be deleted when Fluent-Bit starts.
                 */
                "deleteIrrecoverableChunks"?: "on" | "off";
                /**
                 * If the input plugin has enabled filesystem storage type, this property sets the maximum number of Chunks that can be up in memory
                 */
                "maxChunksUp"?: number;
                /**
                 * If http_server option has been enabled in the Service section, this option registers a new endpoint where internal metrics of the storage layer can be consumed
                 */
                "metrics"?: "on" | "off";
                /**
                 * Select an optional location in the file system to store streams and chunks of data/
                 */
                "path"?: string;
                /**
                 * Configure the synchronization mode used to store the data into the file system
                 */
                "sync"?: "normal" | "full";
            };
        };
    };
}
/**
 * ClusterFluentBitConfig is the Schema for the cluster-level fluentbitconfigs API
 */
export declare class ClusterFluentBitConfig extends Model<IClusterFluentBitConfig> implements IClusterFluentBitConfig {
    "apiVersion": IClusterFluentBitConfig["apiVersion"];
    "kind": IClusterFluentBitConfig["kind"];
    "metadata"?: IClusterFluentBitConfig["metadata"];
    "spec"?: IClusterFluentBitConfig["spec"];
    static apiVersion: IClusterFluentBitConfig["apiVersion"];
    static kind: IClusterFluentBitConfig["kind"];
    static is: import("@kubernetes-models/base").TypeMetaGuard<IClusterFluentBitConfig>;
    constructor(data?: ModelData<IClusterFluentBitConfig>);
}
